@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: pkt_buffer.c,v 1.15 2002/12/18 12:40:28 bazsi Exp $
+ * $Id: pkt_buffer.c,v 1.16 2003/01/20 15:30:25 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -132,7 +132,7 @@ static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 				if (self->super.writable)
 					(*self->super.writable) = 1;
 			}
-			else if (res != 0) {
+			else {
 				/* this is slow, because of another memory move
 				 * but this is run rarely anyway */
 				struct buffer_node *item;
