@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: werror.c,v 1.4.2.1 2001/10/24 10:43:22 bazsi Exp $
+ * $Id: werror.c,v 1.6 2002/11/04 09:10:47 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -50,7 +50,7 @@ int syslog_flag = 0;
 
 int error_fd = STDERR_FILENO;
 
-#define BUF_SIZE 1024
+#define MAX_BUF_SIZE 65536
 
 static int write_file(int level, UINT32 length, UINT8 *data);
 
@@ -59,12 +59,12 @@ int (*error_write)(int level, UINT32 length, UINT8 *data) = write_file;
 #if HAVE_SYSLOG
 static int write_syslog(int level UNUSED, UINT32 length, UINT8 *data)
 {
-  UINT8 string_buffer[BUF_SIZE];
+  UINT8 string_buffer[length + 1];
   UINT32 to_copy;
   
   /* Make sure the message is properly terminated with \0. */
   /* snprintf(string_buffer, (BUF_SIZE > length) ? BUF_SIZE : length, "%s", data); */
-  to_copy = MIN(length, BUF_SIZE - 1);
+  to_copy = MIN(length, sizeof(string_buffer) - 1);
   memcpy(string_buffer, data, to_copy);
   string_buffer[to_copy] = 0;
 
@@ -115,13 +115,14 @@ void set_error_ignore(void)
 
 void msg_vformat(int level, const char *f, va_list args)
 {
-	UINT8 errorbuf[BUF_SIZE];
 	int length;
 	va_list args_copy;
 	va_copy(args_copy, args);
 	
 	length = c_vformat_length(f, args);
-	if (length <= BUF_SIZE) {
+	if (length <= MAX_BUF_SIZE) {
+		char errorbuf[length];
+		
 		va_copy(args, args_copy);
 		c_vformat_write(f, sizeof(errorbuf), errorbuf, args);
 		MSG_WRITE(level, length, errorbuf);
